@@ -2,7 +2,7 @@
 
 package YATT::Registry;
 use strict;
-use warnings FATAL => qw(all);
+use warnings qw(FATAL all NONFATAL misc);
 use Carp;
 use UNIVERSAL;
 
