@@ -34,6 +34,7 @@ use YATT::Types -base => __PACKAGE__
 		   cf_driver
 		   cf_docs cf_tmpl
 		   cf_charset
+		   cf_language
 		   cf_debug_allowed_ip
 		   cf_translator_param
 		   cf_user_config
@@ -211,6 +212,7 @@ END
   }
 
   if (my $sub = $cgi->can('charset')) {
+    # print "\n\n", YATT::Util::terse_dump(CONFIG => $config);
     $sub->($cgi, $config->{cf_charset} || 'utf-8');
   }
 
@@ -234,7 +236,7 @@ sub force_parameter_convention {
   my @deleted;
   foreach my $name ($cgi->param) {
     next if $name =~ $PARAM_CONVENTION;
-    push @deleted, [$name => $cgi->param($name)];
+    push @deleted, [$name => $cgi->multi_param($name)];
     $cgi->delete($name);
   }
   @deleted;
@@ -530,6 +532,11 @@ sub new_cgi {
     die "Can't load any of cgi classes";
   }
 
+  if ($class eq "CGI" and not $class->can("multi_param")) {
+    require YATT::Util::CGICompat;
+    import YATT::Util::CGICompat;
+  }
+
   # 1. To make sure passing 'public' parameters only.
   # 2. To avoid CGI::Simple eval()
   if (UNIVERSAL::isa($oldcgi, $class)) {
